@@ -85,8 +85,6 @@ text_drake_graph_impl <- function(
     show_output_files = show_output_files,
     hover = FALSE
   )
-  config$logger$minor("begin text_drake_graph()")
-  on.exit(config$logger$minor("end text_drake_graph()"), add = TRUE)
   render_text_drake_graph(
     graph_info = graph_info,
     nchar = nchar,
